def printDiamond(size):
    # your code goes here
    n=size
    l1=list(map(chr,range(97,123)))
    x=l1[n-1::-1]+l1[1:n]
    m=len('-'.join(x))
    for i in range(1,n):
        print('-'.join(l1[n-1:n-i:-1]+l1[n-i:n]).center(m,'-'))
    for i in range(n,0,-1):
        print('-'.join(l1[n-1:n-i:-1]+l1[n-i:n]).center(m,'-'))    





from setuptools import setup, find_packages

setup(
    name="diamondsBySummer",
    version="0.1.1",
    packages=find_packages(),
    install_requires=[],  # Add dependencies here if needed
    author="Rishi",
    description="diamonds by summer",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)

